import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import './constants.dart';

final color = Color(0x61ffffff);
ThemeData theme(BuildContext context) {
  return ThemeData(
    // scaffoldBackgroundColor: Colors.white,
    fontFamily: "SourceSansPro",
    // appBarTheme: appBarTheme(context),
    textTheme: const TextTheme(
      bodyLarge: TextStyle(color: kTextColor),
      bodyMedium: TextStyle(color: kTextColor),
      labelLarge: TextStyle(color: kTextColor),
    ),
    inputDecorationTheme: inputDecorationTheme(),
    primarySwatch: Colors.blue,
    visualDensity: VisualDensity.adaptivePlatformDensity,
    textSelectionTheme: TextSelectionThemeData(cursorColor: kTextColor),
    colorScheme: {
      'light': ColorScheme.light(primary: kPrimaryColor),
      'dark': ColorScheme.dark(),
    }[Theme.of(context).brightness.toString().split('.').last],
  );
}

InputDecorationTheme inputDecorationTheme() {
  return const InputDecorationTheme(
    labelStyle: TextStyle(color: kTextColor),
    floatingLabelStyle: TextStyle(color: kTextColor),
    contentPadding: EdgeInsets.symmetric(vertical: 12, horizontal: 16),
    enabledBorder: OutlineInputBorder(
      borderSide: BorderSide(color: borderInputColor),
      borderRadius: BorderRadius.all(Radius.circular(8)),
      gapPadding: 10,
    ),
    focusedBorder: OutlineInputBorder(
      borderSide: BorderSide(color: Colors.blue),
      borderRadius: BorderRadius.all(Radius.circular(8)),
      gapPadding: 10,
    ),
    border: OutlineInputBorder(
      borderSide: BorderSide(color: borderInputColor),
      borderRadius: BorderRadius.all(Radius.circular(8)),
    ),
  );
}

AppBarTheme appBarTheme(BuildContext context) {
  return AppBarTheme(
      color: Colors.white,
      elevation: 0,
      systemOverlayStyle:
          const SystemUiOverlayStyle(statusBarColor: Colors.white),
      // actionsIconTheme: IconThemeData(color: Colors.green, size: 36),
      iconTheme: Theme.of(context).iconTheme,
      toolbarTextStyle: Theme.of(context).textTheme.bodyMedium,
      titleTextStyle: Theme.of(context).textTheme.titleLarge);
}
