import 'package:example/components/ppy_primary_button.dart';
import 'package:example/constants/constants.dart';
import 'package:example/constants/size_config.dart';
import 'package:example/screens/claim_case_detail/update_document_screen.dart';
import 'package:example/screens/home/components/claim_cases.graphql.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

class Body extends HookWidget {
  const Body({super.key});

  @override
  Widget build(BuildContext context) {
    final claimId = ModalRoute.of(context)?.settings.arguments as String;

    final client = useGraphQLClient();

    final claimCase = client.readFragment$ClaimCases(idFields: {
      "id": claimId,
      "__typename": "claim_cases",
    });

    final H8 = getProportionateScreenHeight(8);

    return Scaffold(
      appBar: AppBar(
        title: Text('Chi tiết yêu cầu'),
        elevation: 1,
      ),
      body: Column(
        children: [
          Expanded(
            child: SingleChildScrollView(
              child: Padding(
                padding: const EdgeInsets.all(16.0),
                child: Container(
                  padding: const EdgeInsets.all(16.0),
                  decoration: BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.circular(8),
                    border: Border.all(
                      color: baseGray20,
                      width: 1,
                    ),
                  ),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        "Thông tin yêu cầu",
                        style: TextStyle(
                          fontSize: 16,
                          fontWeight: FontWeight.bold,
                          height: 1.5,
                          color: baseGray90,
                          letterSpacing: 0.04,
                        ),
                      ),
                      SizedBox(
                        height: getProportionateScreenHeight(16),
                      ),
                      renderItem(
                        title: "Ngày yêu cầu",
                        value: "13/04/2023",
                      ),
                      SizedBox(
                        height: getProportionateScreenHeight(12),
                      ),
                      Text(
                        "Thông tin thăm khám",
                        style: TextStyle(
                          fontSize: 16,
                          fontWeight: FontWeight.bold,
                          height: 1.5,
                          color: baseGray90,
                          letterSpacing: 0.04,
                        ),
                      ),
                      renderItem(
                        title: "Người được bảo hiểm",
                        value: claimCase?.insured_person.name ?? "",
                      ),
                      SizedBox(
                        height: H8,
                      ),
                      renderItem(
                        title: "Quyền lợi",
                        value: claimCase?.insured_benefit_type.comment ?? "",
                      ),
                      SizedBox(
                        height: H8,
                      ),
                      renderItem(
                        title: "Cơ sở y tế/bệnh viện thăm khám",
                        value: claimCase?.medical_provider_name ?? "",
                      ),
                      SizedBox(
                        height: H8,
                      ),
                      renderItem(
                        title: "Chẩn đoán",
                        value: claimCase?.diseases ?? "",
                      ),
                      SizedBox(
                        height: getProportionateScreenHeight(12),
                      ),
                      Text(
                        "Thông tin chứng từ",
                        style: TextStyle(
                          fontSize: 16,
                          fontWeight: FontWeight.bold,
                          height: 1.5,
                          color: baseGray90,
                          letterSpacing: 0.04,
                        ),
                      ),
                      SizedBox(
                        height: H8,
                      ),
                      Text(
                        "Đơn thuốc",
                        style: TextStyle(
                          fontSize: 14,
                          height: 1.5,
                          fontWeight: FontWeight.bold,
                          color: baseGray90,
                          letterSpacing: 0.04,
                        ),
                      ),
                      GridView.count(
                        crossAxisCount: 4, // Number of images per row
                        shrinkWrap: true,
                        crossAxisSpacing: 12,
                        mainAxisSpacing: 12,
                        physics:
                            NeverScrollableScrollPhysics(), // Disable scroll
                        children: List.generate(
                          claimCase?.claim_documents.length ?? 0,
                          (index) {
                            final imageUrl =
                                claimCase?.claim_documents[index].file?.url ??
                                    "";
                            //  final List<ImageProvider> _imageProviders =
                            //          claimCase?.claim_documents.map((file) => file?.).toList();

                            return InkWell(
                              onTap: () {
                                // MultiImageProvider multiImageProvider =
                                //     MultiImageProvider(
                                //         initialIndex: index, _imageProviders);
                                // showImageViewerPager(
                                //     context, multiImageProvider,
                                //     swipeDismissible: true,
                                //     doubleTapZoomable: true);
                              },
                              child: ClipRRect(
                                borderRadius: BorderRadius.circular(8),
                                child: Image.network(
                                  imageUrl,
                                  fit: BoxFit.fill,
                                ),
                              ),
                            );
                          },
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
          Padding(
            padding: EdgeInsets.only(
              top: getProportionateScreenHeight(16),
              left: getProportionateScreenWidth(16),
              right: getProportionateScreenWidth(16),
              bottom: getProportionateScreenHeight(37),
            ),
            child: PPYPrimaryButton(
              press: () {
                Navigator.pushNamed(context, UpdateDocumentScreen.routeName,
                    arguments: {
                      "claimId": claimId,
                      "benefitName":
                          claimCase?.insured_benefit_type.comment ?? "",
                      "benefitValue":
                          claimCase?.insured_benefit_type.value ?? "",
                    });
              },
              text: "Nộp bổ sung chứng từ",
            ),
          ),
        ],
      ),
    );
  }

  Widget renderItem({
    required String title,
    required String value,
  }) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          title,
          style: TextStyle(
            fontSize: 14,
            height: 1.5,
            color: baseGray60,
            letterSpacing: 0.04,
          ),
        ),
        Text(
          value,
          style: TextStyle(
            fontSize: 14,
            height: 1.5,
            color: baseGray90,
            letterSpacing: 0.04,
            fontWeight: FontWeight.bold,
          ),
        ),
      ],
    );
  }
}
