import 'package:example/constants/constants.dart';
import 'package:example/constants/size_config.dart';
import 'package:example/provider/user_provider.dart';
import 'package:example/schema.graphql.dart';
import 'package:example/screens/home/components/claim_cases.graphql.dart';
import 'package:example/screens/home/components/create_claim_case_button.dart';
import 'package:example/screens/login/login_screen.dart';
import 'package:example/screens/submit_claim/select_insured_person.dart';
import 'package:example/services/shared_preferences_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_svg/svg.dart';
import 'dart:math' as math;
import 'package:graphql_flutter/graphql_flutter.dart';
import 'package:provider/provider.dart';

import 'claim_case_item.dart';

class Body extends HookWidget {
  @override
  Widget build(BuildContext context) {
    final role = Enum$identity_roles_enum.InsuredPerson.name;
    final userProvider = Provider.of<UserProvider>(context);
    final dataClaimCases = useQuery$getClaimCases(
      Options$Query$getClaimCases(
        pollInterval: Duration(minutes: 3),
        context: Context.fromList(
          [
            HttpLinkHeaders(
              headers: {
                "x-hasura-role": role,
              },
            ),
          ],
        ),
      ),
    );

    final parsedData = Query$getClaimCases.fromJson(
      dataClaimCases.result.data ??
          {
            "claim_cases": [],
            "__typename": "",
          },
    );

    final isLoading = dataClaimCases.result.isLoading;

    if (isLoading) {
      return Center(
        child: SizedBox(
          width: 24,
          height: 24,
          child: CircularProgressIndicator(),
        ),
      );
    }

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        elevation: 1,
        actions: [
          IconButton(
            icon: Icon(Icons.logout),
            onPressed: () {
              // handle search button press
              sharedPreferenceService.clearToken().then(
                (value) {
                  userProvider.clearUserId();
                  Navigator.of(context).pushNamedAndRemoveUntil(
                    LoginScreen.routerName,
                    (route) => false,
                  );
                },
              );
            },
          ),
        ],
      ),
      body: CustomScrollView(
        slivers: [
          SliverPersistentHeader(
            delegate: _SliverAppBarDelegate(
              minHeight: 120.0,
              maxHeight: 120.0,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(20),
                    child: CreateClaimCaseButton(
                      onTap: () {
                        Navigator.pushNamed(
                          context,
                          SelectInsuredPersonScreen.routerName,
                        );
                      },
                    ),
                  ),
                  Padding(
                    padding: EdgeInsets.symmetric(horizontal: 20),
                    child: Text(
                      'Yêu cầu đã gửi',
                      style: TextStyle(
                        color: kTextColor,
                        fontWeight: FontWeight.bold,
                        fontSize: 16,
                      ),
                    ),
                  ),
                ],
              ),
            ),
            pinned: true,
          ),
          SliverList(
            delegate: parsedData.claim_cases.isEmpty
                ? SliverChildListDelegate(
                    [
                      SizedBox(
                        height: getProportionateScreenHeight(100),
                      ),
                      Center(
                        child: SizedBox(
                          width: 180,
                          height: 180,
                          child:
                              SvgPicture.asset("/assets/icons/EmptyState.svg"),
                        ),
                      ),
                      SizedBox(
                        height: getProportionateScreenHeight(13),
                      ),
                      Text(
                        "Bạn chưa có Yêu cầu giải quyết quyền\n lợi bảo hiểm nào",
                        style: TextStyle(
                          color: Colors.grey,
                          fontSize: 16,
                        ),
                        textAlign: TextAlign.center,
                      ),
                    ],
                  )
                : SliverChildBuilderDelegate(
                    (BuildContext context, int index) {
                      final item = parsedData.claim_cases[index];

                      return Padding(
                        padding: const EdgeInsets.symmetric(
                          horizontal: 20,
                          vertical: 8,
                        ),
                        child: ClaimCaseItem(item: item),
                      );
                    },
                    childCount: parsedData.claim_cases.length,
                  ),
          ),
        ],
      ),
    );
  }
}

class _SliverAppBarDelegate extends SliverPersistentHeaderDelegate {
  _SliverAppBarDelegate({
    required this.minHeight,
    required this.maxHeight,
    required this.child,
  });

  final double minHeight;
  final double maxHeight;
  final Widget child;

  @override
  double get minExtent => minHeight;

  @override
  double get maxExtent => math.max(maxHeight, minHeight);

  @override
  Widget build(
    BuildContext context,
    double shrinkOffset,
    bool overlapsContent,
  ) {
    return Container(
      color: Colors.white,
      child: SizedBox.expand(child: child),
    );
  }

  @override
  bool shouldRebuild(_SliverAppBarDelegate oldDelegate) {
    return maxHeight != oldDelegate.maxHeight ||
        minHeight != oldDelegate.minHeight ||
        child != oldDelegate.child;
  }
}
