import 'package:example/components/ppy_checkbox.dart';
import 'package:example/components/ppy_primary_button.dart';
import 'package:example/constants/size_config.dart';
import 'package:example/screens/submit_claim/input_treatment_info_screen.dart';
import 'package:example/screens/submit_claim/user.graphql.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';

class SelectBenefitScreen extends StatefulHookWidget {
  static String routerName = '/select-benefit';
  const SelectBenefitScreen({super.key});

  @override
  _SelectBenefitScreenState createState() => _SelectBenefitScreenState();
}

class _SelectBenefitScreenState extends State<SelectBenefitScreen> {
  var selectedBenefitIndex = -1;

  @override
  Widget build(BuildContext context) {
    SizeConfig().init(context);
    final Fragment$BareInsuredCertificate certificate = ModalRoute.of(context)!
        .settings
        .arguments as Fragment$BareInsuredCertificate;

    final benefits = certificate.insured_person.benefits?.data;

    final Spacing20 = getProportionateScreenWidth(20);

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        elevation: 1,
      ),
      body: Container(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: EdgeInsets.only(
                left: getProportionateScreenWidth(18),
                top: getProportionateScreenHeight(20),
              ),
              child: Text(
                "Chọn quyền lợi bảo hiểm",
                style: TextStyle(fontWeight: FontWeight.w600, fontSize: 16),
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(20),
              child: Container(
                padding: EdgeInsets.only(bottom: 10, top: 10),
                decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.circular(10),
                  boxShadow: [
                    BoxShadow(
                      color: Colors.grey.withOpacity(0.2),
                      spreadRadius: 1,
                      blurRadius: 5,
                      offset: Offset(0, 1), // changes position of shadow
                    ),
                  ],
                ),
                child: Column(
                  children:
                      List.generate(benefits?.length ?? 0, (index) => index)
                          .map(
                    (index) {
                      final benefit = benefits?[index];

                      return Column(
                        children: [
                          Padding(
                            padding: EdgeInsets.only(top: 8, bottom: 5),
                            child: PPYCheckbox(
                              title: benefit?.comment ?? "",
                              value: selectedBenefitIndex == index,
                              onChanged: (value) {
                                setState(() {
                                  selectedBenefitIndex = index;
                                });
                              },
                            ),
                          ),
                          index == (benefits!.length - 1)
                              ? Container()
                              : Divider(),
                        ],
                      );
                    },
                  ).toList(),
                ),
              ),
            ),
            const Spacer(),
            Padding(
              padding: EdgeInsets.only(
                left: Spacing20,
                right: Spacing20,
                top: 20,
                bottom: getProportionateScreenHeight(37),
              ),
              child: PPYPrimaryButton(
                disabled: selectedBenefitIndex == -1,
                text: "Tiếp tục",
                press: () {
                  Navigator.pushNamed(
                    context,
                    InputTreatmentInfoScreen.routerName,
                    arguments: {
                      "benefitName": benefits?[selectedBenefitIndex].comment,
                      "benefitValue": benefits?[selectedBenefitIndex].value,
                      "certificateId": certificate.id,
                      "insuredPersonName": certificate.insured_person.name,
                      "insuredPersonId": certificate.insured_person.id,
                    },
                  );
                },
              ),
            ),
          ],
        ),
      ),
    );
  }
}
