import 'package:example/components/ppy_checkbox.dart';
import 'package:example/components/ppy_primary_button.dart';
import 'package:example/constants/size_config.dart';
import 'package:example/provider/user_provider.dart';
import 'package:example/schema.graphql.dart';
import 'package:example/screens/submit_claim/select_benefit_screen.dart';
import 'package:example/screens/submit_claim/user.graphql.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'package:provider/provider.dart';

class SelectInsuredPersonScreen extends StatefulHookWidget {
  static String routerName = '/select-insured-person';
  const SelectInsuredPersonScreen({super.key});

  @override
  _SelectInsuredPersonScreenState createState() =>
      _SelectInsuredPersonScreenState();
}

class _SelectInsuredPersonScreenState extends State<SelectInsuredPersonScreen> {
  var selectedIndex = -1;

  @override
  Widget build(BuildContext context) {
    SizeConfig().init(context);
    final userProvider = Provider.of<UserProvider>(context);
    final role = Enum$identity_roles_enum.InsuredPersonUser.name;
    final userData = useQuery$identity_users_by_pk(
      Options$Query$identity_users_by_pk(
        context: Context.fromList(
          [
            HttpLinkHeaders(
              headers: {
                "x-hasura-role": role,
              },
            ),
          ],
        ),
        variables: Variables$Query$identity_users_by_pk(
          id: userProvider.userId,
        ),
      ),
    );

    if (userData.result.data == null ||
        (userData.result.data != null && userData.result.data!.isEmpty)) {
      return Scaffold(
        appBar: AppBar(
          title: const Text('Bảo lãnh thuốc'),
        ),
        body: Center(
          child: CircularProgressIndicator(),
        ),
      );
    }

    final user = Fragment$identityUsersByPK.fromJson(
        userData.result.data!["identity_users_by_pk"]);

    var allCertificates = <Fragment$BareInsuredCertificate>[];

    user.insured_persons.forEach((insuredPerson) {
      print(insuredPerson.name);
      insuredPerson.insured_certificates.forEach((insuredCertificate) {
        allCertificates.add(insuredCertificate);

        // ignore: unnecessary_null_comparison
        if (insuredCertificate.children_insured_certificates != null) {
          final childrenCertificates = insuredCertificate
              .children_insured_certificates
              .where((certificate) =>
                  certificate.status !=
                  Enum$insured_certificate_statuses_enum.EXPIRED.name)
              .toList();

          allCertificates.addAll(childrenCertificates);
        }

        if (insuredCertificate.parent_insured_certificate != null &&
            insuredCertificate.parent_insured_certificate?.status !=
                Enum$insured_certificate_statuses_enum.EXPIRED.name) {
          allCertificates.add(insuredCertificate.parent_insured_certificate
              as Fragment$InsuredCertificate);
        }
      });
    });

    allCertificates = allCertificates.fold([], (list, certificate) {
      final exists = list.any((e) => e.id == certificate.id);
      if (!exists &&
          certificate.policy.policy_setting?.has_tpa == true &&
          certificate
                  .policy.policy_setting?.la_can_submit_claim_for_dependant ==
              true) {
        list.add(certificate);
      }

      return list;
    });

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        elevation: 1,
      ),
      body: Container(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: EdgeInsets.only(
                left: getProportionateScreenWidth(18),
                top: getProportionateScreenHeight(20),
              ),
              child: Text(
                "Chọn người được bảo hiểm",
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: 16,
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(20),
              child: Container(
                padding: EdgeInsets.only(bottom: 10, top: 10),
                decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.circular(10),
                  boxShadow: [
                    BoxShadow(
                      color: Colors.grey.withOpacity(0.2),
                      spreadRadius: 1,
                      blurRadius: 5,
                      offset: Offset(0, 1), // changes position of shadow
                    ),
                  ],
                ),
                child: Column(
                  children:
                      List.generate(allCertificates.length, (index) => index)
                          .map(
                            (index) => Column(
                              children: [
                                Padding(
                                  padding: EdgeInsets.only(top: 8, bottom: 5),
                                  child: PPYCheckbox(
                                    title: allCertificates[index]
                                        .insured_person
                                        .name,
                                    value: selectedIndex == index,
                                    onChanged: (value) {
                                      setState(
                                        () {
                                          selectedIndex = index;
                                        },
                                      );
                                    },
                                  ),
                                ),
                                index == (allCertificates.length - 1)
                                    ? Container()
                                    : Divider(),
                              ],
                            ),
                          )
                          .toList(),
                ),
              ),
            ),
            Spacer(),
            Padding(
              padding: EdgeInsets.only(
                left: getProportionateScreenWidth(20),
                right: getProportionateScreenWidth(20),
                bottom: 37,
                top: 20,
              ),
              child: PPYPrimaryButton(
                disabled: selectedIndex == -1,
                text: "Tiếp tục",
                press: () {
                  Navigator.pushNamed(
                    context,
                    SelectBenefitScreen.routerName,
                    arguments: allCertificates[selectedIndex],
                  );
                },
              ),
            ),
          ],
        ),
      ),
    );
  }
}
