import 'dart:io';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';

// ignore_for_file: library_private_types_in_public_api
// ignore: must_be_immutable
class PaperImageUpload extends StatefulWidget {
  PaperImageUpload({
    super.key,
    required this.paper,
    this.onAddImage,
    this.onRemoveImage,
    required this.images,
  });

  final Map<String, dynamic> paper;
  List<XFile> images;

  final Function(List<XFile> images, String paperType)? onAddImage;
  final Function(int index, String paperType)? onRemoveImage;

  @override
  _PaperImageUploadState createState() => _PaperImageUploadState();
}

class _PaperImageUploadState extends State<PaperImageUpload> {
  Future<void> _getImage() async {
    final picker = ImagePicker();
    final pickedFiles = await picker.pickMultiImage(requestFullMetadata: true);
    if (widget.onAddImage != null) {
      widget.onAddImage!(pickedFiles, widget.paper["type"]);
    }
  }

  void _removeImage(int index) {
    if (widget.onRemoveImage != null) {
      widget.onRemoveImage!(index, widget.paper["type"]);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.only(
            left: 16,
            right: 16,
            bottom: 8,
          ),
          child: Text(
            widget.paper["description"] ?? "",
            style: const TextStyle(fontSize: 14, fontWeight: FontWeight.bold),
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(
            left: 16,
            right: 16,
          ),
          child: GridView.builder(
            shrinkWrap: true,
            physics: const NeverScrollableScrollPhysics(),
            gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: 4,
              crossAxisSpacing: 8,
              mainAxisSpacing: 8,
            ),
            itemCount: widget.images.length + 1,
            itemBuilder: (BuildContext context, int index) {
              if (index == 0) {
                return InkWell(
                  onTap: _getImage,
                  child: Container(
                    decoration: BoxDecoration(
                      color: Colors.black12,
                      borderRadius: BorderRadius.circular(8),
                      border: Border.all(
                        color: Colors.black12,
                        width: 1,
                      ),
                    ),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        Container(
                          decoration: BoxDecoration(
                            color: Colors.black87,
                            borderRadius: BorderRadius.circular(24),
                          ),
                          child: const Padding(
                            padding: EdgeInsets.all(2),
                            child: Icon(
                              Icons.add,
                              color: Colors.white,
                              size: 18,
                            ),
                          ),
                        ),
                        const Padding(
                          padding: EdgeInsets.only(top: 8),
                          child: Text(
                            "Thêm ảnh",
                            style: TextStyle(
                              fontSize: 12,
                              color: Colors.black,
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                );
              } else {
                final imageUrl = widget.images[index - 1].path;
                return Stack(
                  children: [
                    InkWell(
                      onTap: () {
                        // MultiImageProvider multiImageProvider =
                        //     MultiImageProvider(
                        //         initialIndex: index - 1, _imageProviders);
                        // showImageViewerPager(context, multiImageProvider,
                        //     swipeDismissible: true, doubleTapZoomable: true);
                      },
                      child: Container(
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(8),
                        ),
                        height: double.infinity,
                        width: double.infinity,
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(8),
                          child: Image.file(
                            File(imageUrl),
                            fit: BoxFit
                                .fill, // <--- Set fit property to BoxFit.cover
                          ),
                        ),
                      ),
                    ),
                    Positioned(
                      top: 0,
                      right: 0,
                      child: InkWell(
                        onTap: () {
                          _removeImage(index - 1);
                        },
                        child: Container(
                          decoration: const BoxDecoration(
                            shape: BoxShape.circle,
                            color: Colors.white,
                          ),
                          child: const Padding(
                            padding: EdgeInsets.all(2),
                            child: Icon(
                              Icons.close,
                              color: Colors.black,
                              size: 18,
                            ),
                          ),
                        ),
                      ),
                    ),
                  ],
                );
              }
            },
          ),
        ),
      ],
    );
  }
}
