import 'package:papaya_sdk/constants/size_config.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:syncfusion_flutter_datepicker/datepicker.dart';

class PPYDateRangePickerWidget extends StatefulWidget {
  const PPYDateRangePickerWidget(
      {Key? key, this.labelText, this.hintText, this.onSelectionChanged})
      : super(key: key);

  final labelText;
  final hintText;
  final Function(DateTime, DateTime)? onSelectionChanged;
  @override
  _PPYDateRangePickerWidgetState createState() =>
      _PPYDateRangePickerWidgetState(labelText, hintText, onSelectionChanged);
}

class _PPYDateRangePickerWidgetState extends State<PPYDateRangePickerWidget> {
  _PPYDateRangePickerWidgetState(
      this.labelText, this.hintText, this.onSelectionChanged);

  PickerDateRange _selectedRange = const PickerDateRange(null, null);

  final labelText;
  final hintText;
  final Function(DateTime, DateTime)? onSelectionChanged;

  void _showDateRangePicker(BuildContext context) async {
    final pickedRange = await showModalBottomSheet<PickerDateRange>(
      context: context,
      builder: (context) {
        return Padding(
          padding: EdgeInsets.only(bottom: getProportionateScreenHeight(20)),
          child: SizedBox(
            height: 500,
            child: SfDateRangePicker(
              navigationMode: DateRangePickerNavigationMode.snap,
              showActionButtons: true,
              selectionMode: DateRangePickerSelectionMode.range,
              initialSelectedRange: _selectedRange,
              onSubmit: (value) {
                final pickedRange = value as PickerDateRange;
                setState(() {
                  _selectedRange = pickedRange;
                });
                Navigator.pop(context, pickedRange);
                if (onSelectionChanged != null &&
                    pickedRange.startDate is DateTime &&
                    pickedRange.endDate is DateTime) {
                  onSelectionChanged!(pickedRange.startDate as DateTime,
                      pickedRange.endDate as DateTime);
                }
              },
              onCancel: () {
                Navigator.pop(context);
              },
            ),
          ),
        );
      },
    );

    if (pickedRange != null) {
      setState(() {
        _selectedRange = pickedRange;
      });
    }
  }

  String? _validateDate(String? value) {
    if (value == null || value.isEmpty) {
      return 'Vui lòng chọn ngày';
    }
    return null;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        _showDateRangePicker(context);
      },
      child: TextFormField(
        readOnly: true,
        onTap: () {
          _showDateRangePicker(context);
        },
        validator: _validateDate,
        decoration: InputDecoration(
          labelText: labelText,
          hintText: hintText,
          border: const OutlineInputBorder(),
          suffixIcon: IconButton(
            icon: const Icon(Icons.calendar_today),
            onPressed: () {
              _showDateRangePicker(context);
            },
          ),
        ),
        controller: TextEditingController(
          text:
              '${_selectedRange.startDate != null ? DateFormat('dd/MM/yyyy').format(_selectedRange.startDate as DateTime) : ""} - ${_selectedRange.endDate != null ? DateFormat('dd/MM/yyyy').format(_selectedRange.endDate as DateTime) : ""}',
        ),
      ),
    );
  }
}
