import 'package:flutter/material.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'package:papaya_sdk/config/client.dart';
import 'package:papaya_sdk/provider/user_provider.dart';
import 'package:papaya_sdk/screens/home/home_screen.dart';
import 'package:papaya_sdk/screens/welcome/welcome_screen.dart';
import 'package:papaya_sdk/services/shared_preferences_service.dart';
import 'package:provider/provider.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:form_builder_validators/form_builder_validators.dart';

import 'constants/route.dart';
import 'constants/theme.dart';

class PapayaWidget extends StatefulWidget {
  const PapayaWidget({super.key});

  @override
  _PapayaWidgetState createState() => _PapayaWidgetState();
}

class _PapayaWidgetState extends State<PapayaWidget> {
  bool _isLoading = true;

  @override
  void initState() {
    super.initState();
    _initPreferences();
  }

  Future<void> _initPreferences() async {
    await initHiveForFlutter();
    await sharedPreferenceService.getSharedPreferencesInstance();

    final token = await sharedPreferenceService.token;

    setState(() {
      _isLoading = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    return _isLoading
        ? const Center(child: CircularProgressIndicator())
        : FutureBuilder<String>(
            future: sharedPreferenceService.token,
            builder: (BuildContext context, AsyncSnapshot<String> snapshot) {
              if (snapshot.hasData) {
                final isLogin = snapshot.data!.isNotEmpty;

                return MultiProvider(
                  providers: [
                    ChangeNotifierProvider(
                      create: (_) => UserProvider(), // add UserProvider
                    ),
                  ],
                  child: GraphQLProvider(
                      client: config.initializeClient(),
                      child: Consumer<UserProvider>(
                        builder: (context, userProvider, child) {
                          return MaterialApp(
                            title: 'Example',
                            theme: theme(context),
                            localizationsDelegates: const [
                              FormBuilderLocalizations.delegate,
                              GlobalMaterialLocalizations.delegate,
                              GlobalWidgetsLocalizations.delegate,
                            ],
                            supportedLocales:
                                FormBuilderLocalizations.supportedLocales,
                            initialRoute: isLogin
                                ? HomeScreen.routerName
                                : WelcomeScreen.routerName,
                            routes: routes,
                          );
                        },
                      )),
                );
              } else {
                return const SizedBox.shrink();
              }
            },
          );
  }
}
