import 'package:papaya_sdk/components/paper_image_upload.dart';
import 'package:papaya_sdk/components/ppy_primary_button.dart';
import 'package:papaya_sdk/schema.graphql.dart';
import 'package:papaya_sdk/screens/claim_case_detail/update_document_success_screen.dart';
import 'package:papaya_sdk/screens/submit_claim/upload_papers.graphql.dart';
import 'package:papaya_sdk/utils/utils.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'package:image_picker/image_picker.dart';
import 'package:mime/mime.dart';
import 'package:http/http.dart' as http;

class UpdateDocumentScreen extends StatefulHookWidget {
  static const routeName = '/upload-document';
  const UpdateDocumentScreen({super.key});

  @override
  State<UpdateDocumentScreen> createState() => _UpdateDocumentScreenState();
}

class _UpdateDocumentScreenState extends State<UpdateDocumentScreen> {
  Map<String, List<XFile>?> list = {};

  bool isLoading = false;
  int numImagesUploaded = 0;

  void onAddImage(List<XFile> images, String paperType) {
    setState(() {
      if (list.containsKey(paperType) == false) {
        if (list.isEmpty) {
          list = {
            paperType: images,
          };
        } else {
          list.addAll({
            paperType: images,
          });
        }
      } else {
        if (list[paperType] == null) {
          list[paperType] = [];
        }
        Set<XFile> existingFiles = Set<XFile>.from(list[paperType]!);
        List<XFile> filteredImages = images.where((XFile image) {
          return !existingFiles.contains(image);
        }).toList();

        list[paperType]!.addAll(filteredImages);
      }
    });
  }

  void onRemoveImage(int index, String paperType) {
    setState(() {
      if (list.containsKey(paperType)) {
        list[paperType]!.removeAt(index);
        if (list[paperType]!.isEmpty) {
          list.remove(paperType);
        }
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    final agrs =
        ModalRoute.of(context)?.settings.arguments as Map<String, String>;
    final benefitValue = agrs['benefitValue'] ?? '';
    final benefitName = agrs['benefitName'] ?? '';
    final claimId = agrs['claimId'] ?? '';
    List<Map<String, dynamic>> papers = getPapersForBenefit(
        fromJson$Enum$insured_benefit_types_enum(benefitValue));
    final role = Enum$identity_roles_enum.InsuredPerson.name;
    final client = useGraphQLClient();

    final insertFileForUseUploadFileHookMutation =
        useMutation$insertFileForUseUploadFileHook(
      WidgetOptions$Mutation$insertFileForUseUploadFileHook(
        fetchPolicy: FetchPolicy.noCache,
        context: Context.fromList(
          [
            HttpLinkHeaders(
              headers: {
                "x-hasura-role": role,
              },
            ),
          ],
        ),
        onCompleted: (data, mutation) {
          numImagesUploaded++;
          if (numImagesUploaded == papers.length) {
            showDialog(
              context: context,
              builder: (BuildContext context) {
                return AlertDialog(
                  title: const Text('Create Claim Case Success'),
                  content: const Text('All images have been uploaded.'),
                  actions: <Widget>[
                    PPYPrimaryButton(
                      text: 'OK',
                      press: () {
                        Navigator.of(context).pop();
                        Navigator.of(context).pushNamedAndRemoveUntil(
                          UpdateDocumentSuccessScreen.routeName,
                          (route) => false,
                        );
                      },
                    ),
                  ],
                );
              },
            );
          }
        },
        onError: (error) {
          print(error);
        },
      ),
    );

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bổ sung chứng từ'),
        elevation: 1,
      ),
      body: Column(
        children: [
          Expanded(
            child: SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Padding(
                    padding: const EdgeInsets.only(
                        left: 16, right: 16, top: 16, bottom: 16),
                    child: Text(
                      benefitName,
                      style: const TextStyle(
                        fontSize: 18,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                  for (int i = 0; i < papers.length; i++)
                    PaperImageUpload(
                      paper: papers[i],
                      onAddImage: onAddImage,
                      onRemoveImage: onRemoveImage,
                      images: list[papers[i]['type']] ?? [],
                    ),
                ],
              ),
            ),
          ),
          Container(
            color: Colors.white,
            padding:
                const EdgeInsets.only(top: 16, left: 16, right: 16, bottom: 37),
            child: PPYPrimaryButton(
              text: 'Xác nhận',
              press: () async {
                List<Input$UploadFileMetadatasInsertInput> inputUploadFiles =
                    [];
                List<dynamic> files = [];

                for (MapEntry<String, List<XFile>?> entry in list.entries) {
                  String key = entry.key;
                  List<XFile>? value = entry.value;
                  if (value != null) {
                    files.addAll(
                      value
                          .map((f) => {
                                "type": key,
                                "file": f,
                              })
                          .toList(),
                    );
                    inputUploadFiles.addAll(
                      value.map((e) {
                        final mimeType = lookupMimeType(e.path);

                        return Input$UploadFileMetadatasInsertInput(
                          docType: fromJson$Enum$DocTypeEnum(key),
                          fileName: e.name,
                          mimeType: mimeType!,
                        );
                      }).toList(),
                    );
                  }
                }

                final result = await client.query$uploadFileMetadatas(
                    Options$Query$uploadFileMetadatas(
                  context: Context.fromList(
                    const [
                      HttpLinkHeaders(
                        headers: {
                          "x-hasura-role": "InsuredPerson",
                        },
                      ),
                    ],
                  ),
                  fetchPolicy: FetchPolicy.noCache,
                  variables: Variables$Query$uploadFileMetadatas(
                    files: inputUploadFiles,
                    id: claimId,
                    fileType: Enum$FileTypeInputEnum.CLAIM,
                  ),
                ));

                final resultUploadFileMetaData =
                    Query$uploadFileMetadatas.fromJson(result.data!);

                for (var metadata
                    in resultUploadFileMetaData.uploadFileMetadatas) {
                  try {
                    final file = files.firstWhere(
                        (p) => p["file"].name == metadata.originalFileName);

                    final mimeType = lookupMimeType(file["file"].path);

                    final bytes = await file["file"].readAsBytes();
                    final blob = bytes.buffer.asUint8List();
                    await http.put(Uri.parse(metadata.uploadUrl),
                        headers: {"Content-Type": mimeType!}, body: blob);

                    final insertFileInput = Input$files_insert_input(
                      url: metadata.publicUrl,
                      bucket_name: metadata.bucketName,
                      name: metadata.fileName,
                      mime_type: mimeType,
                      claim_document:
                          Input$claim_documents_obj_rel_insert_input(
                        data: Input$claim_documents_insert_input(
                          claim_case_id: claimId,
                          type: fromJson$Enum$claim_document_types_enum(
                              file['type']),
                          source: Enum$claim_sources_enum.CARE_APP,
                        ),
                      ),
                    );

                    insertFileForUseUploadFileHookMutation.runMutation(
                        Variables$Mutation$insertFileForUseUploadFileHook(
                      input: insertFileInput,
                      fileConstraint:
                          Enum$files_constraint.files_claim_document_id_key,
                      updateColumns: [
                        Enum$files_update_column.url,
                        Enum$files_update_column.bucket_name,
                        Enum$files_update_column.name,
                        Enum$files_update_column.mime_type,
                      ],
                    ));

                    setState(() {
                      isLoading = false;
                    });
                  } catch (e) {
                    setState(
                      () {
                        isLoading = false;
                      },
                    );
                    print(e);
                  }
                }
              },
            ),
          ),
        ],
      ),
    );
  }
}
