import 'package:papaya_sdk/components/ppy_primary_button.dart';
import 'package:papaya_sdk/constants/constants.dart';
import 'package:papaya_sdk/constants/size_config.dart';
import 'package:papaya_sdk/screens/login/components/login.graphql.dart';
import 'package:papaya_sdk/screens/otp/otp_screen.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder/flutter_form_builder.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_svg/svg.dart';
import 'package:form_builder_validators/form_builder_validators.dart';

class Body extends StatefulHookWidget {
  const Body({super.key});

  @override
  State<Body> createState() => _BodyState();
}

class _BodyState extends State<Body> {
  final _formKey = GlobalKey<FormBuilderState>();

  String? customValidatorMethod(dynamic value) {
    if (value == null) {
      return "Số điện thoại/Email không để trống";
    }
    final isEmail = emailValidatorRegExp.hasMatch(value);
    final email = isEmail ? value : null;
    final phone =
        isEmail || phoneValidatorRegExp.hasMatch(value) == false ? null : value;

    if (value != null && phone == null && email == null) {
      return "Số điện thoại/Email không hợp lệ";
    }

    return null;
  }

  @override
  Widget build(BuildContext context) {
    final mutation = useMutation$CreateOtpByPhoneOrEmail(
      WidgetOptions$Mutation$CreateOtpByPhoneOrEmail(
        onCompleted: (data, mutation) {
          if (data?["createOtp"] == null) {
            setState(
              () {
                _formKey.currentState?.invalidateField(
                    name: 'emailOrPhone',
                    errorText: 'Số điện thoại/Email không đúng');
              },
            );
            return;
          }

          final text = _formKey.currentState?.fields["emailOrPhone"]?.value;
          final email = emailValidatorRegExp.hasMatch(text) ? text : null;
          final phone = emailValidatorRegExp.hasMatch(text) ||
                  phoneValidatorRegExp.hasMatch(text) == false
              ? null
              : text;
          final result = Mutation$CreateOtpByPhoneOrEmail$createOtp.fromJson(
            data!["createOtp"],
          );
          if (result.success) {
            Navigator.pushReplacementNamed(
              context,
              OtpScreen.routerName,
              arguments: {
                "email": email,
                "phone": phone,
              },
            );
          }
        },
        onError: (error) {
          setState(
            () {
              _formKey.currentState?.invalidateField(
                  name: 'emailOrPhone',
                  errorText: 'Số điện thoại/Email không đúng');
            },
          );
        },
      ),
    );

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        backgroundColor: Colors.white,
        elevation: 1,
      ),
      body: FormBuilder(
        key: _formKey,
        child: Padding(
          padding: EdgeInsets.symmetric(
            horizontal: getProportionateScreenWidth(20),
          ),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: SingleChildScrollView(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      SizedBox(
                        height: getProportionateScreenHeight(16),
                      ),
                      Container(
                        padding: EdgeInsets.symmetric(
                          horizontal: getProportionateScreenWidth(16),
                          vertical: getProportionateScreenHeight(16),
                        ),
                        decoration: BoxDecoration(
                          color: Colors.white,
                          borderRadius: BorderRadius.circular(10),
                          border: Border.all(
                            color: Colors.grey,
                          ),
                        ),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            SvgPicture.asset(
                              "lib/assets/icons/Logo.svg",
                              package: 'papaya_sdk',
                            ),
                            SizedBox(
                              height: getProportionateScreenHeight(16),
                            ),
                            Text(
                              "Để sử dụng chức năng bảo lãnh lãnh thuốc, Papaya cần liên kết tài khoản xác thực của bạn với Ứng dụng Long Châu.",
                              style: TextStyle(
                                fontSize: 14,
                              ),
                            ),
                            SizedBox(
                              height: getProportionateScreenHeight(8),
                            ),
                            Text(
                              "Việc xác thực và liên kết chỉ xảy ra một lần, đảm bảo bạn sử dụng đúng tài khoản đã đăng ký với công ty bảo hiểm Bảo Minh và được chúng tôi quản lý.",
                              style: TextStyle(
                                fontSize: 14,
                              ),
                            ),
                            SizedBox(
                              height: getProportionateScreenHeight(8),
                            ),
                            RichText(
                              text: TextSpan(
                                children: [
                                  TextSpan(
                                    text: "Cần hỗ trợ vui lòng liên hệ ",
                                    style: TextStyle(
                                      fontSize: 14,
                                      color: Colors.black,
                                    ),
                                  ),
                                  TextSpan(
                                    text: "1900 252 570",
                                    style: TextStyle(
                                      fontSize: 14,
                                      color: Colors.blue,
                                      fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          ],
                        ),
                      ),
                      SizedBox(
                        height: getProportionateScreenHeight(20),
                      ),
                      FormBuilderTextField(
                        autovalidateMode: AutovalidateMode.onUserInteraction,
                        name: 'emailOrPhone',
                        autofillHints: [
                          AutofillHints.email,
                          AutofillHints.telephoneNumber
                        ],
                        autocorrect: false,
                        autofocus: true,
                        decoration: const InputDecoration(
                          labelText: "Số điện thoại/Email",
                          hintText: "Nhập Số điện thoại/Email",
                        ),
                        onChanged: (val) {
                          setState(() {
                            _formKey.currentState?.fields['emailOrPhone']
                                ?.validate();
                          });
                        },
                        validator: FormBuilderValidators.compose(
                            [(value) => customValidatorMethod(value)]),
                        keyboardType: TextInputType.number,
                        textInputAction: TextInputAction.next,
                      ),
                      SizedBox(
                        height: getProportionateScreenHeight(8),
                      ),
                    ],
                  ),
                ),
              ),
              Padding(
                padding: EdgeInsets.only(
                  bottom: getProportionateScreenHeight(20.0),
                ),
                child: PPYPrimaryButton(
                  loading: mutation.result.isLoading,
                  disabled: _formKey
                          .currentState?.fields['emailOrPhone']?.hasError ??
                      _formKey.currentState?.fields['emailOrPhone']?.value ==
                              null ||
                          mutation.result.isLoading == true,
                  text: "Xác thực",
                  press: () {
                    if (_formKey.currentState!.validate()) {
                      final text =
                          _formKey.currentState?.fields["emailOrPhone"]?.value;
                      final isEmail = emailValidatorRegExp.hasMatch(text);
                      final email = isEmail ? text : null;
                      final phone = isEmail ||
                              phoneValidatorRegExp.hasMatch(text) == false
                          ? null
                          : text;
                      mutation.runMutation(
                        variables: Variables$Mutation$CreateOtpByPhoneOrEmail(
                          email: email,
                          phone: phone,
                        ),
                      );
                    }
                  },
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
