import 'dart:async';

import 'package:papaya_sdk/provider/user_provider.dart';
import 'package:papaya_sdk/screens/home/home_screen.dart';
import 'package:papaya_sdk/screens/login/components/login.graphql.dart';
import 'package:papaya_sdk/screens/otp/verify_otp.graphql.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:otp_text_field/otp_text_field.dart';
import 'package:otp_text_field/style.dart';
import 'package:papaya_sdk/constants/size_config.dart';
import 'package:provider/provider.dart';

import '../../../services/shared_preferences_service.dart';

class Body extends StatefulHookWidget {
  const Body({super.key});

  @override
  State<Body> createState() => _BodyState();
}

class _BodyState extends State<Body> {
  final otp = "";
  final otpController = TextEditingController();

  final loading = false;

  late Timer _timer;
  int _secondsRemaining = 0;

  @override
  void initState() {
    super.initState();
    _secondsRemaining = 180;
    _timer = Timer.periodic(const Duration(seconds: 1), (timer) {
      setState(() {
        _secondsRemaining--;
      });
      if (_secondsRemaining == 0) {
        _timer.cancel();
      }
    });
  }

  @override
  void dispose() {
    _timer.cancel();
    super.dispose();
  }

  void _retry() {
    _timer.cancel();
    setState(() {
      _secondsRemaining = 180;
    });
    _timer = Timer.periodic(const Duration(seconds: 1), (timer) {
      setState(() {
        _secondsRemaining--;
      });
      if (_secondsRemaining == 0) {
        _timer.cancel();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    final userProvider = Provider.of<UserProvider>(context);
    // final userId = userProvider.userId;
    final Map<String, dynamic>? args =
        ModalRoute.of(context)?.settings.arguments as Map<String, dynamic>?;
    final email = args?["email"];
    final phone = args?["phone"];

    print(args);

    final verifyOtpMutation = useMutation$verifyOtp(
      WidgetOptions$Mutation$verifyOtp(
        onCompleted: (data, mutation) async {
          final token = data?["phoneLogin"]?["token"];

          if (token != null) {
            await sharedPreferenceService.setToken(token);
            await userProvider.setUserId();
            Navigator.of(context).pushNamedAndRemoveUntil(
              HomeScreen.routerName,
              (route) => false,
            );
          }
        },
        onError: (error) {
          print("error: $error");
        },
      ),
    );

    final createOtpMutation = useMutation$CreateOtpByPhoneOrEmail(
      WidgetOptions$Mutation$CreateOtpByPhoneOrEmail(
        onCompleted: (data, mutation) {
          if (data?["createOtp"]?["success"] == true) {
            _retry();
          }
        },
        onError: (error) {
          print("error: $error");
        },
      ),
    );

    final minutes = _secondsRemaining ~/ 60;
    final seconds = _secondsRemaining % 60;
    final timeString =
        '${minutes.toString().padLeft(2, '0')}:${seconds.toString().padLeft(2, '0')}';

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        backgroundColor: Colors.white,
        elevation: 1,
      ),
      body: Form(
        child: Padding(
          padding: EdgeInsets.symmetric(
            horizontal: getProportionateScreenWidth(20),
          ),
          child: Center(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  email == null
                      ? "Vui lòng nhập OTP được gửi về Số điện thoại"
                      : "Vui lòng nhập OTP được gửi về email",
                  style: const TextStyle(
                    fontSize: 16,
                  ),
                ),
                Text(
                  email ?? phone ?? "",
                  style: const TextStyle(
                      fontSize: 16, fontWeight: FontWeight.bold),
                ),
                SizedBox(
                  height: getProportionateScreenHeight(24),
                ),
                OTPTextField(
                  // controller: otpController,
                  length: 6,
                  width: MediaQuery.of(context).size.width - 20,
                  textFieldAlignment: MainAxisAlignment.spaceAround,
                  fieldWidth: 48,
                  fieldStyle: FieldStyle.box,
                  outlineBorderRadius: 15,
                  style: const TextStyle(fontSize: 17),
                  onChanged: (pin) {
                    print("Changed: $pin");
                  },
                  onCompleted: (pin) {
                    verifyOtpMutation.runMutation(
                      Variables$Mutation$verifyOtp(
                        otp: pin,
                        email: email,
                        phone: phone,
                      ),
                    );
                  },
                ),
                SizedBox(
                  height: getProportionateScreenHeight(24),
                ),
                RichText(
                  text: TextSpan(
                    children: [
                      const TextSpan(
                        text: "Gửi lại OTP sau ",
                        style: TextStyle(
                          color: Colors.black,
                        ),
                      ),
                      _secondsRemaining == 0
                          ? TextSpan(
                              style: const TextStyle(
                                color: Colors.blue,
                                fontWeight: FontWeight.bold,
                              ),
                              text: 'Thử lại',
                              recognizer: TapGestureRecognizer()
                                ..onTap = () {
                                  createOtpMutation.runMutation(
                                    variables:
                                        Variables$Mutation$CreateOtpByPhoneOrEmail(
                                      email: email,
                                      phone: phone,
                                    ),
                                  );
                                },
                            )
                          : TextSpan(
                              text: timeString,
                              style: const TextStyle(
                                color: Colors.black,
                                fontWeight: FontWeight.bold,
                              ),
                            ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
