import 'package:papaya_sdk/components/ppy_primary_button.dart';
import 'package:papaya_sdk/constants/size_config.dart';
import 'package:papaya_sdk/screens/submit_claim/paper_screen.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder/flutter_form_builder.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:form_builder_validators/form_builder_validators.dart';
import 'package:intl/intl.dart';

class InputTreatmentInfoScreen extends StatefulHookWidget {
  static String routerName = '/input-treatment-info';
  const InputTreatmentInfoScreen({super.key});

  @override
  State<InputTreatmentInfoScreen> createState() =>
      _InputTreatmentInfoScreenState();
}

class _InputTreatmentInfoScreenState extends State<InputTreatmentInfoScreen> {
  final _formKey = GlobalKey<FormBuilderState>();
  bool loading = false;
  final List<String> errors = [];

  final medicalProviderNameController = TextEditingController();
  final diagnosisController = TextEditingController();

  var eventStarAt;
  var physicalExaminationDate;
  var admissionDate;
  var dischargeDate;

  void _onSubmit(Map<String, dynamic> params) {
    if (_formKey.currentState!.saveAndValidate()) {
      DateTimeRange? admissionDischargeDate =
          _formKey.currentState?.fields["admissionDischargeDate"]?.value;
      FocusScope.of(context).unfocus();
      final args = {
        "medicalProviderName":
            _formKey.currentState?.fields["medicalProviderName"]?.value,
        "diagnosis": _formKey.currentState?.fields["diagnosis"]?.value,
        "eventStarAt": _formKey.currentState?.fields["eventStarAt"]?.value,
        "physicalExaminationDate":
            _formKey.currentState?.fields["physicalExaminationDate"]?.value,
        "admissionDate": admissionDischargeDate?.start,
        "dischargeDate": admissionDischargeDate?.end
      };
      Navigator.pushNamed(context, PaperScreen.routerName, arguments: {
        ...args,
        ...params,
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    final params =
        ModalRoute.of(context)!.settings.arguments as Map<String, String?>;

    String benefitValue = params["benefitValue"] ?? "";

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        elevation: 1,
      ),
      body: FormBuilder(
        key: _formKey,
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 20),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Text(
                'Thông tin thăm khám',
                style: TextStyle(fontWeight: FontWeight.bold, fontSize: 16),
              ),
              SizedBox(
                height: getProportionateScreenHeight(20),
              ),
              FormBuilderTextField(
                autovalidateMode: AutovalidateMode.onUserInteraction,
                name: "medicalProviderName",
                onChanged: (value) {
                  setState(() {
                    _formKey.currentState?.fields['medicalProviderName']
                        ?.validate();
                  });
                },
                validator: FormBuilderValidators.compose([
                  FormBuilderValidators.required(
                      errorText:
                          "Vui lòng nhập Cơ sở y tế/bệnh viện thăm khám"),
                ]),
                autocorrect: false,
                autofocus: true,
                decoration: const InputDecoration(
                  labelText: "Cơ sở y tế/bệnh viện thăm khám",
                  hintText: "Nhập Cơ sở y tế/bệnh viện thăm khám",
                ),
              ),
              SizedBox(
                height: getProportionateScreenHeight(20),
              ),
              buildDatesRequirementByBenefit(benefitValue: benefitValue),
              SizedBox(
                height: getProportionateScreenHeight(20),
              ),
              FormBuilderTextField(
                name: "diagnosis",
                autovalidateMode: AutovalidateMode.onUserInteraction,
                controller: diagnosisController,
                onChanged: (value) {
                  setState(() {
                    _formKey.currentState?.fields['diagnosis']?.validate();
                  });
                },
                validator: FormBuilderValidators.compose([
                  FormBuilderValidators.required(
                    errorText: "Vui lòng nhập Chẩn đoán",
                  ),
                ]),
                autocorrect: false,
                autofocus: true,
                decoration: const InputDecoration(
                  labelText: "Chẩn đoán",
                  hintText: "Nhập Chẩn đoán",
                ),
                onSubmitted: (_) {
                  _onSubmit(params);
                },
              ),
              SizedBox(
                height: getProportionateScreenHeight(20),
              ),
              const Spacer(),
              Padding(
                padding: EdgeInsets.only(
                  top: 20,
                  bottom: getProportionateScreenHeight(17),
                ),
                child: PPYPrimaryButton(
                  // disabled: diagnosisController.value.text.isEmpty ?? true,

                  text: "Tiếp tục",
                  press: () => _onSubmit(params),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }

  Widget buildDatesRequirementByBenefit({required String benefitValue}) {
    switch (benefitValue) {
      case "Life":
        return FormBuilderDateTimePicker(
          name: 'eventStarAt',
          autovalidateMode: AutovalidateMode.onUserInteraction,
          initialEntryMode: DatePickerEntryMode.calendar,
          inputType: InputType.date,
          format: DateFormat('dd/MM/yyyy'),
          locale: const Locale('vi', 'VN'),
          decoration: InputDecoration(
            labelText: 'Ngày sự kiện bảo hiểm',
            hintText: "Ngày sự kiện bảo hiểm",
            suffixIcon: IconButton(
              icon: const Icon(Icons.calendar_month),
              onPressed: () {
                _formKey.currentState!.fields['eventStarAt']?.didChange(null);
              },
            ),
          ),
          validator: FormBuilderValidators.compose([
            FormBuilderValidators.required(
              errorText: "Vui lòng chọn ngày",
            ),
          ]),
          onChanged: (value) {
            setState(() {
              _formKey.currentState?.fields['eventStarAt']?.validate();
            });
          },
          // locale: const Locale.fromSubtags(languageCode: 'fr'),
        );
      case "Accident":
        return Column(children: [
          FormBuilderDateTimePicker(
            name: 'eventStarAt',
            autovalidateMode: AutovalidateMode.onUserInteraction,
            initialEntryMode: DatePickerEntryMode.calendar,
            inputType: InputType.date,
            format: DateFormat('dd/MM/yyyy'),
            locale: const Locale('vi', 'VN'),
            decoration: InputDecoration(
              labelText: 'Ngày sự kiện bảo hiểm',
              hintText: "Ngày sự kiện bảo hiểm",
              suffixIcon: IconButton(
                icon: const Icon(Icons.calendar_month),
                onPressed: () {
                  _formKey.currentState!.fields['eventStarAt']?.didChange(null);
                },
              ),
            ),
            validator: FormBuilderValidators.compose([
              FormBuilderValidators.required(
                errorText: "Vui lòng chọn ngày",
              ),
            ]),
            onChanged: (value) {
              setState(() {
                _formKey.currentState?.fields['eventStarAt']?.validate();
              });
            },
            // locale: const Locale.fromSubtags(languageCode: 'fr'),
          ),
          SizedBox(
            height: getProportionateScreenHeight(20),
          ),
          FormBuilderDateTimePicker(
            name: 'physicalExaminationDate',
            autovalidateMode: AutovalidateMode.onUserInteraction,
            initialEntryMode: DatePickerEntryMode.calendar,
            inputType: InputType.date,
            format: DateFormat('dd/MM/yyyy'),
            locale: const Locale('vi', 'VN'),
            decoration: InputDecoration(
              labelText: 'Ngày thăm khám',
              hintText: "Ngày thăm khám",
              suffixIcon: IconButton(
                icon: const Icon(Icons.calendar_month),
                onPressed: () {
                  _formKey.currentState!.fields['physicalExaminationDate']
                      ?.didChange(null);
                },
              ),
            ),
            validator: FormBuilderValidators.compose([
              FormBuilderValidators.required(
                errorText: "Vui lòng chọn ngày",
              ),
            ]),
            onChanged: (value) {
              setState(() {
                _formKey.currentState?.fields['physicalExaminationDate']
                    ?.validate();
              });
            },
            // locale: const Locale.fromSubtags(languageCode: 'fr'),
          )
        ]);
      case "Dental":
      case "OutPatient":
        return FormBuilderDateTimePicker(
          name: 'physicalExaminationDate',
          autovalidateMode: AutovalidateMode.onUserInteraction,
          initialEntryMode: DatePickerEntryMode.calendar,
          inputType: InputType.date,
          format: DateFormat('dd/MM/yyyy'),
          locale: const Locale('vi', 'VN'),
          decoration: InputDecoration(
            labelText: 'Ngày thăm khám',
            hintText: "Ngày thăm khám",
            suffixIcon: IconButton(
              icon: const Icon(Icons.calendar_month),
              onPressed: () {
                _formKey.currentState!.fields['physicalExaminationDate']
                    ?.didChange(null);
              },
            ),
          ),
          validator: FormBuilderValidators.compose([
            FormBuilderValidators.required(
              errorText: "Vui lòng chọn ngày",
            ),
          ]),
          onChanged: (value) {
            setState(() {
              _formKey.currentState?.fields['physicalExaminationDate']
                  ?.validate();
            });
          },
          // locale: const Locale.fromSubtags(languageCode: 'fr'),
        );
      case "InPatient":
      case "Maternity":
        return FormBuilderDateRangePicker(
          name: 'admissionDischargeDate',
          firstDate: DateTime(1970),
          lastDate: DateTime(2030),
          format: DateFormat('dd/MM/yyyy'),
          confirmText: "Xác nhận",
          style: const TextStyle(
            color: Colors.black,
          ),
          onChanged: (value) {
            setState(() {
              _formKey.currentState?.fields['admissionDischargeDate']
                  ?.validate();
            });
          },
          validator: FormBuilderValidators.compose([
            FormBuilderValidators.required(
              errorText: "Vui lòng chọn ngày",
            ),
          ]),
          locale: const Locale('vi', 'VN'),
          decoration: InputDecoration(
            labelText: 'Ngày vào viện và ngày ra viện',
            hintText: 'Ngày vào viện và ngày ra viện',
            suffixIcon: IconButton(
              icon: const Icon(Icons.calendar_month),
              onPressed: () {
                _formKey.currentState!.fields['admissionDischargeDate']
                    ?.didChange(null);
              },
            ),
          ),
        );
      default:
        return Container();
    }
  }
}
