import 'package:papaya_sdk/components/paper_image_upload.dart';
import 'package:papaya_sdk/components/ppy_primary_button.dart';
import 'package:papaya_sdk/constants/size_config.dart';
import 'package:papaya_sdk/schema.graphql.dart';
import 'package:papaya_sdk/screens/submit_claim/review_screen.dart';
import 'package:papaya_sdk/utils/utils.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:image_picker/image_picker.dart';

class PaperScreen extends StatefulHookWidget {
  static String routerName = '/papers';
  const PaperScreen({super.key});

  @override
  State<PaperScreen> createState() => _PaperScreenState();
}

class _PaperScreenState extends State<PaperScreen> {
  Map<String, List<XFile>?> list = {};

  void onAddImage(List<XFile> images, String paperType) {
    setState(() {
      if (list.containsKey(paperType) == false) {
        if (list.isEmpty) {
          list = {
            paperType: images,
          };
        } else {
          list.addAll({
            paperType: images,
          });
        }
      } else {
        if (list[paperType] == null) {
          list[paperType] = [];
        }
        Set<XFile> existingFiles = Set<XFile>.from(list[paperType]!);
        List<XFile> filteredImages = images.where((XFile image) {
          return !existingFiles.contains(image);
        }).toList();

        list[paperType]!.addAll(filteredImages);
      }
    });
  }

  void onRemoveImage(int index, String paperType) {
    setState(() {
      if (list.containsKey(paperType)) {
        list[paperType]!.removeAt(index);
        if (list[paperType]!.isEmpty) {
          list.remove(paperType);
        }
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    final Map<String, dynamic> params =
        ModalRoute.of(context)!.settings.arguments as Map<String, dynamic>;
    final String benefitValue = params['benefitValue'];

    // final List<ImageProvider> _imageProviders =
    //     _selectedImages.map((e) => FileImage(File(e.path))).toList();
    List<Map<String, dynamic>> papers = getPapersForBenefit(
        fromJson$Enum$insured_benefit_types_enum(benefitValue));

    final isEnabledButton = papers.every((paper) {
      if (paper["required"] == true &&
          (list.containsKey(paper['type']) == false ||
              (list.containsKey(paper['type']) &&
                  list[paper['type']]!.isEmpty))) return false;

      return true;
    });

    return Scaffold(
      appBar: AppBar(
        title: const Text('Bảo lãnh thuốc'),
        elevation: 1,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: EdgeInsets.only(
                left: getProportionateScreenWidth(16),
                top: getProportionateScreenWidth(16)), //
            child: const Text(
              'Thông tin đơn thuốc',
              style: TextStyle(
                fontSize: 16,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
          Padding(
            padding: EdgeInsets.only(
                left: getProportionateScreenWidth(16),
                bottom: getProportionateScreenWidth(16)), //
            child: const Text(
              'Đơn thuốc có chữ ký của Bác sĩ điều trị',
              style: TextStyle(
                fontSize: 14,
              ),
            ),
          ),
          Expanded(
            child: SingleChildScrollView(
                child: Column(
              children: [
                for (int i = 0; i < papers.length; i++)
                  Padding(
                    padding: EdgeInsets.only(top: i > 0 ? 20.0 : 0.0),
                    child: PaperImageUpload(
                      paper: papers[i],
                      onAddImage: onAddImage,
                      onRemoveImage: onRemoveImage,
                      images: list[papers[i]['type']] ?? [],
                    ),
                  ),
              ],
            )),
          ),
        ],
      ),
      bottomNavigationBar: Container(
        // color: Colors.white,
        decoration: BoxDecoration(
          color: Colors.white, // Set background color to white
          boxShadow: [
            BoxShadow(
              color: Colors.black.withOpacity(0.1),
              spreadRadius: 0,
              blurRadius: 10,
              offset: const Offset(0, -4), // changes position of shadow
            ),
          ],
        ),
        child: Padding(
          padding:
              const EdgeInsets.only(left: 20, right: 20, bottom: 37, top: 20),
          child: PPYPrimaryButton(
            disabled: isEnabledButton == false,
            press: () {
              Navigator.pushNamed(
                context,
                ReviewScreen.routerName,
                arguments: {
                  "papers": list,
                  ...params,
                },
              );
            },
            text: "Tiếp tục",
          ),
        ),
      ),
    );
  }
}
