import 'dart:io';

import 'package:papaya_sdk/components/ppy_primary_button.dart';
import 'package:papaya_sdk/constants/size_config.dart';
import 'package:papaya_sdk/provider/user_provider.dart';
import 'package:papaya_sdk/schema.graphql.dart';
import 'package:papaya_sdk/screens/submit_claim/create_claim.graphql.dart';
import 'package:papaya_sdk/screens/submit_claim/submit_successful_screen.dart';
import 'package:papaya_sdk/screens/submit_claim/upload_papers.graphql.dart';
import 'package:papaya_sdk/utils/utils.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:image_picker/image_picker.dart';
import 'package:graphql_flutter/graphql_flutter.dart';
import 'package:mime/mime.dart';
import 'package:intl/intl.dart';
import 'package:provider/provider.dart';
import 'package:easy_image_viewer/easy_image_viewer.dart';
import 'package:http/http.dart' as http;

class ReviewScreen extends StatefulHookWidget {
  static String routerName = '/review';
  const ReviewScreen({super.key});

  @override
  State<ReviewScreen> createState() => _ReviewScreenState();
}

class _ReviewScreenState extends State<ReviewScreen> {
  bool isLoading = false;
  int numImagesUploaded = 0;

  @override
  Widget build(BuildContext context) {
    final userProvider = Provider.of<UserProvider>(context);
    final Map<String, dynamic> args =
        ModalRoute.of(context)!.settings.arguments as Map<String, dynamic>;
    final Map<String, List<XFile>?> papers =
        args['papers'] as Map<String, List<XFile>?>;
    final String insuredPersonName = args['insuredPersonName'] as String;
    final String benefitName = args['benefitName'] as String;
    final String certificateId = args['certificateId'] as String;
    final String medicalProviderName = args['medicalProviderName'] as String;
    final String diagnosis = args['diagnosis'] as String;
    final String benefitValue = args['benefitValue'] as String;
    final eventStarAt = args['eventStarAt'];
    final physicalExaminationDate = args['physicalExaminationDate'];
    final admissionDate = args['admissionDate'];
    final dischargeDate = args['dischargeDate'];
    final role = Enum$identity_roles_enum.InsuredPerson.name;

    final client = useGraphQLClient();

    final insertFileForUseUploadFileHookMutation =
        useMutation$insertFileForUseUploadFileHook(
      WidgetOptions$Mutation$insertFileForUseUploadFileHook(
        fetchPolicy: FetchPolicy.noCache,
        context: Context.fromList(
          [
            HttpLinkHeaders(
              headers: {
                "x-hasura-role": role,
              },
            ),
          ],
        ),
        onCompleted: (data, mutation) {
          numImagesUploaded++;
          if (numImagesUploaded == papers.length) {
            setState(() {
              isLoading = false;
            });
            showDialog(
              context: context,
              builder: (BuildContext context) {
                return AlertDialog(
                  title: const Text('Create Claim Case Success'),
                  content: const Text('All images have been uploaded.'),
                  actions: <Widget>[
                    PPYPrimaryButton(
                      text: 'OK',
                      press: () {
                        Navigator.of(context).pop();
                        Navigator.of(context).pushNamedAndRemoveUntil(
                          SubmitSuccessfulScreen.routerName,
                          (route) => false,
                        );
                      },
                    ),
                  ],
                );
              },
            );
          }
        },
        onError: (error) {
          print(error);
        },
      ),
    );

    final createClaimMutation = useMutation$createClaim(
      WidgetOptions$Mutation$createClaim(
        context: Context.fromList(
          [
            HttpLinkHeaders(
              headers: {
                "x-hasura-role": role,
              },
            ),
          ],
        ),
        onCompleted: (data, mutation) async {
          if (data != null && data["submitClaim"]["success"] == true) {
            final claimId = data["submitClaim"]["claimId"];

            List<Input$UploadFileMetadatasInsertInput> inputUploadFiles = [];
            List<dynamic> files = [];

            for (MapEntry<String, List<XFile>?> entry in papers.entries) {
              String key = entry.key;
              List<XFile>? value = entry.value;
              if (value != null) {
                files.addAll(
                  value
                      .map((f) => {
                            "type": key,
                            "file": f,
                          })
                      .toList(),
                );
                inputUploadFiles.addAll(
                  value.map((e) {
                    final mimeType = lookupMimeType(e.path);

                    return Input$UploadFileMetadatasInsertInput(
                      docType: fromJson$Enum$DocTypeEnum(key),
                      fileName: e.name,
                      mimeType: mimeType!,
                    );
                  }).toList(),
                );
              }
            }

            final result = await client
                .query$uploadFileMetadatas(Options$Query$uploadFileMetadatas(
              context: Context.fromList(
                [
                  HttpLinkHeaders(
                    headers: {
                      "x-hasura-role": role,
                    },
                  ),
                ],
              ),
              fetchPolicy: FetchPolicy.noCache,
              variables: Variables$Query$uploadFileMetadatas(
                files: inputUploadFiles,
                id: claimId,
                fileType: Enum$FileTypeInputEnum.CLAIM,
              ),
            ));

            final resultUploadFileMetaData =
                Query$uploadFileMetadatas.fromJson(result.data!);

            for (var metadata in resultUploadFileMetaData.uploadFileMetadatas) {
              try {
                final file = files.firstWhere(
                    (p) => p["file"].name == metadata.originalFileName);

                final mimeType = lookupMimeType(file["file"].path);

                final bytes = await file["file"].readAsBytes();
                final blob = bytes.buffer.asUint8List();
                await http.put(Uri.parse(metadata.uploadUrl),
                    headers: {"Content-Type": mimeType!}, body: blob);

                final insertFileInput = Input$files_insert_input(
                  url: metadata.publicUrl,
                  bucket_name: metadata.bucketName,
                  name: metadata.fileName,
                  mime_type: mimeType,
                  claim_document: Input$claim_documents_obj_rel_insert_input(
                    data: Input$claim_documents_insert_input(
                      claim_case_id: claimId,
                      type:
                          fromJson$Enum$claim_document_types_enum(file['type']),
                      source: Enum$claim_sources_enum.CARE_APP,
                    ),
                  ),
                );

                insertFileForUseUploadFileHookMutation.runMutation(
                    Variables$Mutation$insertFileForUseUploadFileHook(
                  input: insertFileInput,
                  fileConstraint:
                      Enum$files_constraint.files_claim_document_id_key,
                  updateColumns: [
                    Enum$files_update_column.url,
                    Enum$files_update_column.bucket_name,
                    Enum$files_update_column.name,
                    Enum$files_update_column.mime_type,
                  ],
                ));
              } catch (e) {
                setState(
                  () {
                    isLoading = false;
                  },
                );
                print(e);
              }
            }
          }
        },
        onError: (error) {
          print(error);
        },
      ),
    );

    return Scaffold(
      appBar: AppBar(
        title: const Text('Xác nhận thông tin'),
        elevation: 1,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Expanded(
            flex: 1,
            child: SingleChildScrollView(
              child: Padding(
                padding: EdgeInsets.symmetric(
                    horizontal: getProportionateScreenWidth(16), vertical: 20),
                child: Container(
                  decoration: BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.circular(8),
                    border: Border.all(
                      color: Colors.black12,
                      width: 1,
                    ),
                  ),
                  child: Padding(
                    padding: EdgeInsets.symmetric(
                      horizontal: getProportionateScreenWidth(16),
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SizedBox(
                          height: getProportionateScreenHeight(16),
                        ),
                        const Text(
                          "Thông tin thăm khám",
                          style: TextStyle(
                            fontSize: 14,
                            fontWeight: FontWeight.bold,
                            color: Colors.black,
                            height: 1.5,
                          ),
                        ),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        const Text(
                          "Người được bảo hiểm",
                          style: TextStyle(
                            fontSize: 14,
                            height: 1.5,
                            color: Colors.grey,
                          ),
                        ),
                        Text(
                          insuredPersonName,
                          style: const TextStyle(
                            fontSize: 14,
                            fontWeight: FontWeight.bold,
                            height: 1.5,
                            color: Colors.black,
                          ),
                        ),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        const Text(
                          "Quyền lợi",
                          style: TextStyle(
                            fontSize: 14,
                            height: 1.5,
                            color: Colors.grey,
                          ),
                        ),
                        Text(
                          benefitName,
                          style: const TextStyle(
                            fontSize: 14,
                            fontWeight: FontWeight.bold,
                            height: 1.5,
                            color: Colors.black,
                          ),
                        ),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        const Text(
                          "Cơ sở y tế/bệnh viện thăm khám",
                          style: TextStyle(
                            fontSize: 14,
                            height: 1.5,
                            color: Colors.grey,
                          ),
                        ),
                        Text(
                          medicalProviderName,
                          style: const TextStyle(
                            fontSize: 14,
                            fontWeight: FontWeight.bold,
                            height: 1.5,
                            color: Colors.black,
                          ),
                        ),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        buildDatesRequirementByBenefit(
                            benefitValue: benefitValue,
                            eventStarAt: eventStarAt,
                            physicalExaminationDate: physicalExaminationDate,
                            admissionDate: admissionDate,
                            dischargeDate: dischargeDate),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        const Text(
                          "Chẩn đoán",
                          style: TextStyle(
                            fontSize: 14,
                            height: 1.5,
                            color: Colors.grey,
                          ),
                        ),
                        Text(
                          diagnosis,
                          style: const TextStyle(
                            fontSize: 14,
                            fontWeight: FontWeight.bold,
                            height: 1.5,
                            color: Colors.black,
                          ),
                        ),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        const Text(
                          "Thông tin chứng từ",
                          style: TextStyle(
                            fontSize: 14,
                            height: 1.5,
                            color: Colors.black,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                        SizedBox(
                          height: getProportionateScreenHeight(8),
                        ),
                        // SizedBox(height: 16),
                        for (MapEntry<String, List<XFile>?> entry
                            in papers.entries)
                          ReviewListImage(
                              papers: papers[entry.key], paperType: entry.key),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ),
          Padding(
            padding:
                const EdgeInsets.only(left: 20, right: 20, bottom: 37, top: 20),
            child: PPYPrimaryButton(
              disabled: createClaimMutation.result.isLoading || isLoading,
              loading: createClaimMutation.result.isLoading || isLoading,
              press: () {
                try {
                  setState(() {
                    isLoading = true;
                  });
                  createClaimMutation.runMutation(
                    Variables$Mutation$createClaim(
                      insuredCertificateId: certificateId,
                      benefitType: benefitValue,
                      diagnosis: diagnosis,
                      requestAmount: 0,
                      dischargeDate: dischargeDate is DateTime
                          ? dischargeDate.toIso8601String()
                          : null,
                      admissionDate: admissionDate is DateTime
                          ? admissionDate.toIso8601String()
                          : null,
                      eventDate: eventStarAt is DateTime
                          ? eventStarAt.toIso8601String()
                          : null,
                      physicalExaminationDate:
                          physicalExaminationDate is DateTime
                              ? physicalExaminationDate.toIso8601String()
                              : null,
                      medicalProviderName: medicalProviderName,
                      source: Enum$claim_sources_enum.CARE_APP.name.toString(),
                      treatmentMethod: null,
                      medicalProviderId: null,
                      paymentAccountNumber: "123",
                      paymentAccountName: "Dung",
                      bankId: "762affbc-3bb0-4c32-85f0-9ca2337dbee7",
                      paymentBankName:
                          "Ngân Hàng TMCP Ngoại Thương Việt Nam (VCB)",
                    ),
                  );
                } catch (e) {
                  setState(() {
                    isLoading = false;
                  });
                  print(e);
                }
              },
              text: "Tiếp tục",
            ),
          ),
        ],
      ),
    );
  }

  Widget buildDatesRequirementByBenefit({
    required String benefitValue,
    DateTime? eventStarAt,
    DateTime? physicalExaminationDate,
    DateTime? admissionDate,
    DateTime? dischargeDate,
  }) {
    switch (benefitValue) {
      case "Life":
        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "Ngày sự kiện bảo hiểm",
              style: TextStyle(
                fontSize: 14,
                height: 1.5,
                color: Colors.grey,
              ),
            ),
            Text(
              eventStarAt != null
                  ? DateFormat('dd/MM/yyyy').format(eventStarAt)
                  : "",
              style: const TextStyle(
                fontSize: 14,
                fontWeight: FontWeight.bold,
                height: 1.5,
                color: Colors.black,
              ),
            ),
          ],
        );
      case "Accident":
      case "OutPatient":
        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "Ngày sự kiện bảo hiểm",
              style: TextStyle(
                fontSize: 14,
                height: 1.5,
                color: Colors.grey,
              ),
            ),
            Text(
              eventStarAt != null
                  ? DateFormat('dd/MM/yyyy').format(eventStarAt)
                  : "",
              style: const TextStyle(
                fontSize: 14,
                fontWeight: FontWeight.bold,
                height: 1.5,
                color: Colors.black,
              ),
            ),
            SizedBox(
              height: getProportionateScreenHeight(8),
            ),
            const Text(
              "Ngày thăm khám",
              style: TextStyle(
                fontSize: 14,
                height: 1.5,
                color: Colors.grey,
              ),
            ),
            Text(
              physicalExaminationDate != null
                  ? DateFormat('dd/MM/yyyy').format(physicalExaminationDate)
                  : "",
              style: const TextStyle(
                fontSize: 14,
                fontWeight: FontWeight.bold,
                height: 1.5,
                color: Colors.black,
              ),
            ),
          ],
        );
      case "Dental":
        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "Ngày thăm khám",
              style: TextStyle(
                fontSize: 14,
                height: 1.5,
                color: Colors.grey,
              ),
            ),
            Text(
              physicalExaminationDate != null
                  ? DateFormat('dd/MM/yyyy').format(physicalExaminationDate)
                  : "",
              style: const TextStyle(
                fontSize: 14,
                fontWeight: FontWeight.bold,
                height: 1.5,
                color: Colors.black,
              ),
            ),
          ],
        );
      case "InPatient":
      case "Maternity":
        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const Text(
              "Ngày vào viện và ngày ra viện",
              style: TextStyle(
                fontSize: 14,
                height: 1.5,
                color: Colors.grey,
              ),
            ),
            Text(
              '${admissionDate != null ? DateFormat('dd/MM/yyyy').format(admissionDate) : ""} - ${dischargeDate != null ? DateFormat('dd/MM/yyyy').format(dischargeDate) : ""}',
              style: const TextStyle(
                fontSize: 14,
                fontWeight: FontWeight.bold,
                height: 1.5,
                color: Colors.black,
              ),
            ),
          ],
        );
      default:
        return Container();
    }
  }
}

class ReviewListImage extends StatelessWidget {
  const ReviewListImage({
    Key? key,
    this.papers,
    this.paperType,
  }) : super(key: key);

  final List<XFile>? papers;
  final String? paperType;

  @override
  Widget build(BuildContext context) {
    final List<ImageProvider>? imageProviders = papers
        ?.map(
          (e) => FileImage(
            File(e.path),
          ),
        )
        .toList();

    print(papers);

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.only(bottom: 8),
          child: Text(
            getPaperName(fromJson$Enum$claim_document_types_enum(paperType!)),
            style: const TextStyle(
              fontWeight: FontWeight.bold,
              fontSize: 14,
              height: 1.5,
              color: Colors.black,
            ),
          ),
        ),
        SizedBox(
          height: getProportionateScreenHeight(100),
          child: GridView.count(
            crossAxisCount: 4, // Number of images per row
            shrinkWrap: true,
            crossAxisSpacing: 12,
            mainAxisSpacing: 12,
            physics: const NeverScrollableScrollPhysics(), // Disable scroll
            children: List.generate(papers?.length ?? 0, (index) {
              final imageUrl = papers?[index].path;

              return InkWell(
                onTap: () {
                  MultiImageProvider multiImageProvider = MultiImageProvider(
                      initialIndex: index, imageProviders ?? []);
                  showImageViewerPager(context, multiImageProvider,
                      swipeDismissible: true, doubleTapZoomable: true);
                },
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(8),
                  child: Image.file(
                    File(imageUrl!),
                    fit: BoxFit.fill,
                  ),
                ),
              );
            }),
          ),
        ),
      ],
    );
  }
}
